@@ -1,4 +1,8 @@
-# tests for proj_linpred and proj_predict
+context('as.matrix.projection')
+library(rstanarm)
+
+# tests for as_matrix
+
 
 set.seed(1235)
 n <- 40
@@ -37,7 +41,8 @@ ns <- 100
 p_gauss <- project(vs_gauss, vind = vind, ns = ns)
 p_binom <- project(vs_binom, vind = vind, ns = ns)
 
-context('as.matrix.projection')
+
+
 test_that("as.matrix.projection returns the relevant variables for gaussian", {
   m <- as.matrix(p_gauss)
   expect_equal(colnames(m), c(names(coef(fit_gauss))[c(1, vind + 1)], 'sigma'))
